%define anolis_release 2

%bcond_without  perl
%bcond_without  ecdsa
%bcond_without  eddsa
%bcond_without  dane_ta
%bcond_with     gost

%{?filter_setup:
%global _ldns_internal_filter /^_ldns[.]so.*/d;
%filter_from_requires %{_ldns_internal_filter}
%filter_from_provides %{_ldns_internal_filter}
%filter_setup
}
%global _ldns_internal _ldns[.]so[.].*
%global __requires_exclude ^(%{_ldns_internal})$
%global __provides_exclude ^(%{_ldns_internal})$

%if %{with perl}
%{?perl_default_filter}
%endif

Name: 		ldns
Version:	1.8.3
Release:	%{anolis_release}%{?dist}
Summary: 	Low-level DNS(SEC) library with API
License: 	BSD-3-Clause
Url: 		https://www.nlnetlabs.nl/%{name}/
Source0: 	https://www.nlnetlabs.nl/downloads/%{name}/%{name}-%{version}.tar.gz
Patch1: 	ldns-1.7.0-multilib.patch
Patch2: 	ldns-1.8-python-dirs.patch
Patch3:         100-ldns-1.8-python-swig.patch
Patch4:         0001-ldns-1.8-develop-swig.patch

BuildRequires: libtool
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: autoconf-archive
BuildRequires: gcc, make
BuildRequires: libpcap-devel
%if %{with dane_ta}
BuildRequires: openssl-devel >= 1.1.0
%else
BuildRequires: openssl-devel >= 1.0.2k
%endif
BuildRequires: gcc-c++
BuildRequires: doxygen
BuildRequires: gnupg2
BuildRequires: python3-devel, swig
%if %{with perl}
BuildRequires: perl-devel
BuildRequires: perl-ExtUtils-MakeMaker
BuildRequires: perl-generators
BuildRequires: perl(Devel::CheckLib)
BuildRequires: perl-interpreter
%endif
Requires: ca-certificates

%description
ldns is a library with the aim to simplify DNS programming in C. All
low-level DNS/DNSSEC operations are supported. We also define a higher
level API which allows a programmer to (for instance) create or sign
packets.

%package devel
Summary: Development package that includes the ldns header files
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig openssl-devel

%description devel
The devel package contains the ldns library and the include files

%package utils
Summary: DNS(SEC) utilities for querying dns
Requires: %{name} = %{version}-%{release}

%description utils
Collection of tools to get, check or alter DNS(SEC) data.

%package -n python3-ldns
Summary: Python3 extensions for ldns
Requires: %{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-ldns}

%description -n python3-ldns
Python3 extensions for ldns

%if %{with perl}
%package -n perl-ldns
Summary: Perl extensions for ldns
Requires: %{name} = %{version}-%{release}

%description -n perl-ldns
Perl extensions for ldns
%endif

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%{?extra_version:%global pkgname %{name}-%{version}%{extra_version}}%{!?extra_version:%global pkgname %{name}-%{version}}

%autosetup -cn %{pkgname} -N
pushd %{pkgname}
%autopatch -p1

rm -f config.guess config.sub ltmain.sh
aclocal
libtoolize -c --install
autoreconf --install

# fixup .pc file
sed -i "s/@includedir@/@includedir@\/ldns/" packaging/libldns.pc.in

# copy common doc files - after here, since it may be patched
cp -pr doc LICENSE README* Changelog ../
cp -p contrib/ldnsx/LICENSE ../LICENSE.ldnsx
cp -p contrib/ldnsx/README ../README.ldnsx
popd

cp -a %{pkgname} %{pkgname}_python3

%build
CFLAGS="%{optflags} -fPIC -fno-strict-aliasing"
CXXFLAGS="%{optflags} -fPIC -fno-strict-aliasing"
LDFLAGS="$RPM_LD_FLAGS -Wl,-z,now -pie"
export CFLAGS CXXFLAGS LDFLAGS

%if %{with gost}
  %global enable_gost --enable-gost
%else
  %global enable_gost --disable-gost
%endif

%if %{with ecdsa}
  %global enable_ecdsa --enable-ecdsa
%else
  %global enable_ecdsa --disable-ecdsa
%endif

%if %{with eddsa}
  %global enable_eddsa --enable-ed25519 --enable-ed448
%else
  %global enable_eddsa --disable-ed25519 --disable-ed448
%endif

%if ! %{with dane_ta}
  %global disable_dane_ta --disable-dane-ta-usage
%endif

%global common_args \\\
  --disable-rpath \\\
  %{enable_gost} %{enable_ecdsa} %{enable_eddsa} %{?disable_dane_ta} \\\
  --with-ca-file=/etc/pki/tls/certs/ca-bundle.trust.crt \\\
  --with-ca-path=/etc/pki/tls/certs/ \\\
  --with-trust-anchor=%{_sharedstatedir}/unbound/root.key \\\
  --disable-static \\\

pushd %{pkgname}_python3

%configure \
  %{common_args} \
  --with-examples \
  --with-drill \
  --with-pyldns PYTHON=%{__python3}

make
%make_build doc

# Multilib conflict avoidance
sed -e "s,-L%{_libdir},," -i packaging/ldns-config

# We cannot use the built-in --with-p5-dns-ldns
%if %{with perl}
  pushd contrib/DNS-LDNS
  LD_LIBRARY_PATH="../../lib:$LD_LIBRARY_PATH" perl \
      Makefile.PL INSTALLDIRS=vendor  INC="-I. -I../.." LIBS="-L../../lib"
  %make_build -j1
  popd
%endif
popd

%install
rm -rf %{buildroot}

pushd %{pkgname}_python3

mkdir -p %{buildroot}%{_libdir}/pkgconfig
%make_install install
%make_install install-doc

rm -rf %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{python3_sitearch}/*.la

%if %{with perl}
  %make_install -j1 -C contrib/DNS-LDNS pure_install
  chmod 755 %{buildroot}%{perl_vendorarch}/auto/DNS/LDNS/LDNS.so
  rm -f %{buildroot}%{perl_vendorarch}/auto/DNS/LDNS/{.packlist,LDNS.bs}
  rm -f %{buildroot}%{perl_archlib}/perllocal.pod
%endif
popd

# don't package xml files
rm doc/*.xml
# don't package building script for install-doc in doc section
rm doc/doxyparse.pl
# remove double set of man pages
rm -rf doc/man

mkdir doc/python
cp %{pkgname}_python3/contrib/python/Changelog doc/python

%files
%license LICENSE
%{_libdir}/libldns.so.3*

%files utils
%{_bindir}/drill
%{_bindir}/ldnsd
%{_bindir}/ldns-chaos
%{_bindir}/ldns-compare-zones
%{_bindir}/ldns-[d-z]*
%{_mandir}/man1/drill*
%{_mandir}/man1/%{name}*

%files devel
%{_libdir}/libldns.so
%{_libdir}/pkgconfig/ldns.pc
%{_bindir}/ldns-config
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_mandir}/man3/%{name}*.3*

%files -n python3-ldns
%license LICENSE.ldnsx
%pycached %{python3_sitearch}/%{name}.py
%pycached %{python3_sitearch}/%{name}x.py
%{python3_sitearch}/_%{name}.so*

%if %{with perl}
%files -n perl-ldns
%{perl_vendorarch}/*
%exclude %dir %{perl_vendorarch}/auto/
%{_mandir}/man3/DNS::LDNS*.3pm.zst
%endif

%files doc
%doc README Changelog README.git README.ldnsx
%doc doc

%changelog
* Wed May 21 2025 zhoujiajia111 <zjl02254423@alibaba-inc.com> - 1.8.3-2
- Rebuild for remove inappropriate build dependencies.

* Wed Mar 15 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 1.8.3-1
- Init from upstream
